@@ -21,7 +21,7 @@ module ChefZero
       def post(request)
         orgname = request.rest_path[1]
         full_results = search(request, orgname)
-        keys = FFI_Yajl::Parser.parse(request.body, :create_additions => false)
+        keys = FFI_Yajl::Parser.parse(request.body)
         partial_results = full_results["rows"].map do |name, uri, doc, search_value|
           data = {}
           keys.each_pair do |key, path|
@@ -124,7 +124,7 @@ module ChefZero
         result = []
         list_data(request, container).each do |name|
           value = get_data(request, container + [name])
-          expanded = expander.call(FFI_Yajl::Parser.parse(value, :create_additions => false), name)
+          expanded = expander.call(FFI_Yajl::Parser.parse(value), name)
           result << [ name, build_uri(request.base_uri, container + [name]), expanded, expand_for_indexing(expanded, index, name) ]
         end
         result = result.select do |name, uri, value, search_value|
